@@ -48,7 +48,7 @@ def shape_air(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax, name='Earth2020.shape_air',
-                               units='m')
+                               units='m', encoding='utf-8')
 
 
 def shape_bathy(lmax=2160):
@@ -75,7 +75,7 @@ def shape_bathy(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax, name='Earth2012.shape_bathy',
-                               units='m')
+                               units='m', encoding='utf-8')
 
 
 def shape_bathy_bed(lmax=2160):
@@ -104,7 +104,8 @@ def shape_bathy_bed(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax,
-                               name='Earth2012.shape_bathy_bed', units='m')
+                               name='Earth2012.shape_bathy_bed', units='m',
+                               encoding='utf-8')
 
 
 def shape_ret(lmax=2160):
@@ -131,7 +132,7 @@ def shape_ret(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax, name='Earth2012.shape_ret',
-                               units='m')
+                               units='m', encoding='utf-8')
 
 
 def topo_air(lmax=2160):
@@ -159,7 +160,7 @@ def topo_air(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax, name='Earth2012.topo_air',
-                               units='m')
+                               units='m', encoding='utf-8')
 
 
 def topo_bathy(lmax=2160):
@@ -188,7 +189,7 @@ def topo_bathy(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax, name='Earth2012.topo_bathy',
-                               units='m')
+                               units='m', encoding='utf-8')
 
 
 def topo_bathy_bed(lmax=2160):
@@ -218,7 +219,8 @@ def topo_bathy_bed(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax,
-                               name='Earth2012.topo_bathy_bed', units='m')
+                               name='Earth2012.topo_bathy_bed', units='m',
+                               encoding='utf-8')
 
 
 def ret(lmax=2160):
@@ -245,7 +247,7 @@ def ret(lmax=2160):
         path=_os_cache('pyshtools'),
     )
     return _SHCoeffs.from_file(fname, lmax=lmax, name='Earth2012.ret',
-                               units='m')
+                               units='m', encoding='utf-8')
 
 
 __all__ = ['shape_air', 'shape_bathy', 'shape_bathy_bed', 'shape_ret',
