@@ -2,6 +2,7 @@
 Historical Datasets related to Earth's Moon.
 '''
 from . import gravity
+from . import topography
 
 
-__all__ = ['gravity']
+__all__ = ['gravity', 'topography']
