@@ -214,6 +214,9 @@ class SHMagGrid(object):
             If present, and if ax is not specified, save the image to the
             specified file.
         """
+        if self.units.lower() == 't':
+            cb_label = '$B_r$, T'
+
         return self.rad.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
@@ -234,12 +237,12 @@ class SHMagGrid(object):
                    minor_tick_interval=[None, None], xlabel=None, ylabel=None,
                    title=None, titlesize=None, colorbar='right',
                    cmap='viridis', cmap_limits=None, cmap_reverse=False,
-                   cb_triangles='neither', cb_label='$B_\\theta$, nT',
+                   cb_triangles='neither', cb_label=r'$B_\theta$, nT',
                    cb_tick_interval=None, grid=False, axes_labelsize=None,
                    tick_labelsize=None, show=True, ax=None, cb_offset=None,
                    cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
                    cb_width=None, fname=None):
-        """
+        r"""
         Plot the theta component of the magnetic field.
 
         Usage
@@ -288,7 +291,7 @@ class SHMagGrid(object):
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
-        cb_label : str, optional, default = '$B_\\theta$, nT'
+        cb_label : str, optional, default = r'$B_\theta$, nT'
             Text label for the colorbar.
         cb_ylabel : str, optional, default = None
             Text label for the y axis of the colorbar
@@ -319,6 +322,9 @@ class SHMagGrid(object):
             If present, and if ax is not specified, save the image to the
             specified file.
         """
+        if self.units.lower() == 't':
+            cb_label = r'$B_\theta$, T'
+
         return self.theta.plot(projection=projection,
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
@@ -339,12 +345,12 @@ class SHMagGrid(object):
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
                  title=None, titlesize=None, colorbar='right',
                  cmap='viridis', cmap_limits=None, cmap_reverse=False,
-                 cb_triangles='neither', cb_label='$B_\phi$, nT',
+                 cb_triangles='neither', cb_label=r'$B_\phi$, nT',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
                  cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
                  cb_width=None, fname=None):
-        """
+        r"""
         Plot the phi component of the magnetic field.
 
         Usage
@@ -393,7 +399,7 @@ class SHMagGrid(object):
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
-        cb_label : str, optional, default = '$B_\phi$, nT'
+        cb_label : str, optional, default = r'$B_\phi$, nT'
             Text label for the colorbar.
         cb_ylabel : str, optional, default = None
             Text label for the y axis of the colorbar
@@ -424,6 +430,9 @@ class SHMagGrid(object):
             If present, and if ax is not specified, save the image to the
             specified file.
         """
+        if self.units.lower() == 't':
+            cb_label = r'$B_\phi$, T'
+
         return self.phi.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
@@ -529,6 +538,9 @@ class SHMagGrid(object):
             If present, and if ax is not specified, save the image to the
             specified file.
         """
+        if self.units.lower() == 't':
+            cb_label = '$|B|$, T'
+
         return self.total.plot(projection=projection,
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
@@ -634,6 +646,9 @@ class SHMagGrid(object):
             If present, and if ax is not specified, save the image to the
             specified file.
         """
+        if self.units.lower() == 't':
+            cb_label = 'Potential, T m'
+
         return self.pot.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
@@ -849,9 +864,9 @@ class SHMagGrid(object):
         _rad = self.rad.to_xarray(title='magnetic field (radial)',
                                   long_name='$B_r$', units=mag_units)
         _theta = self.theta.to_xarray(title='magnetic field (theta)',
-                                      long_name='$B_\\theta$', units=mag_units)
+                                      long_name=r'$B_\theta$', units=mag_units)
         _phi = self.phi.to_xarray(title='magnetic field (phi)',
-                                  long_name='$B_\\phi$', units=mag_units)
+                                  long_name=r'$B_\phi$', units=mag_units)
         _pot = self.pot.to_xarray(title='magnetic field potential',
                                   long_name='potential', units=pot_units)
 
